==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/sv.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivitetsflöde",
    "An error occurred while loading activities" : "Något gick snett vid inläsning av aktiviteter",
    "No activity yet" : "Inga aktiviteter ännu",
    "Load more activities" : "Ladda fler aktiviteter",
    "Copied!" : "Kopierad!",
    "Not supported!" : "Stöds ej!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "Home" : "Hem",
    "{name} (invisible)" : "{namn} (osynlig)",
    "{name} (restricted)" : "{namn} (begränsad)",
    "in {path}" : "i {path}",
    "This stream will show events like additions, changes & shares" : "Flödet visar aktiviteter så som tillägg, ändringar och delningar",
    "There are no events for this filter" : "Det finns inga aktiviteter för detta filter",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "Open file" : "Öppna fil",
    "Personal activity feed for %s" : "Personligt aktivitetsflöde för %s",
    "Your feed URL is invalid" : "URL:en för flödet är felaktig.",
    "Your settings have been updated." : "Dina inställningar har uppdaterats.",
    "Settings have been updated." : "Inställningarna har blivit uppdaterade.",
    "All activities" : "Alla aktiviteter",
    "By others" : "Andras aktivitet",
    "By you" : "Min aktivitet",
    "\"remote user\"" : "\"externanvändare\"",
    "Hello %s" : "Hej %s",
    "Hello %s," : "Hej %s,",
    "There was some activity at %s" : "Det var lite aktivitet på %s",
    "_and %n more _::_and %n more _" : ["och %n till","och %n till"],
    ", " : ",",
    "%s and %s" : "%s och %s",
    "Mail" : "E-post",
    "Stream" : "Flödet",
    "Activity" : "Aktivitetsflödet",
    "Activity feed" : "Aktivitetsflöde",
    "Send activity emails" : "Skicka aktivitets-epost",
    "Default settings" : "Förvalda inställningar",
    "Configure the default activity settings for new users." : "Ställ in aktivitetsinställningar för nya användare",
    "List your own actions in the stream" : "Visa dina egna aktiviteter i aktivitetsflödet",
    "Notify about your own actions via email" : "Skicka notifieringsmail gällande dina egna aktiviteter",
    "You need to set up your email address before you can receive notification emails." : "Du måste ställa in din e-postadress innan du kan ta emot e-postmeddelanden.",
    "Send emails:" : "Skicka e-post:",
    "As soon as possible" : "Så snart som möjligt",
    "Hourly" : "Timvis",
    "Daily" : "Dagligen",
    "Weekly" : "Varje vecka",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Välj vilka typer av aktiviteter du vill ha en notis om via e-post och vilka som ska dyka upp i aktivitetsflödet.",
    "Choose which activities you want to see in your stream." : "Välj vilka aktiviteter du vill se i ditt flöde.",
    "Settings" : "Inställningar",
    "Enable RSS feed" : "Aktivera RSS-flöde",
    "RSS feed" : "RSS-flöde",
    "No more events to load" : "Inga fler aktiviteter.",
    "Files" : "Filer",
    "Activity notification" : "Notis om aktivitet"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/sv.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivitetsflöde",
    "An error occurred while loading activities" : "Något gick snett vid inläsning av aktiviteter",
    "No activity yet" : "Inga aktiviteter ännu",
    "Load more activities" : "Ladda fler aktiviteter",
    "Copied!" : "Kopierad!",
    "Not supported!" : "Stöds ej!",
    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
    "Home" : "Hem",
    "{name} (invisible)" : "{namn} (osynlig)",
    "{name} (restricted)" : "{namn} (begränsad)",
    "in {path}" : "i {path}",
    "This stream will show events like additions, changes & shares" : "Flödet visar aktiviteter så som tillägg, ändringar och delningar",
    "There are no events for this filter" : "Det finns inga aktiviteter för detta filter",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "Open file" : "Öppna fil",
    "Personal activity feed for %s" : "Personligt aktivitetsflöde för %s",
    "Your feed URL is invalid" : "URL:en för flödet är felaktig.",
    "Your settings have been updated." : "Dina inställningar har uppdaterats.",
    "Settings have been updated." : "Inställningarna har blivit uppdaterade.",
    "All activities" : "Alla aktiviteter",
    "By others" : "Andras aktivitet",
    "By you" : "Min aktivitet",
    "\"remote user\"" : "\"externanvändare\"",
    "Activity notification for %s" : "Notis om aktivitet för %s",
    "Hello %s" : "Hej %s",
    "Hello %s," : "Hej %s,",
    "There was some activity at %s" : "Det var lite aktivitet på %s",
    "_and %n more _::_and %n more _" : ["och %n till","och %n till"],
    ", " : ",",
    "%s and %s" : "%s och %s",
    "Mail" : "E-post",
    "Stream" : "Flödet",
    "Activity" : "Aktivitetsflödet",
    "This application enables users to view actions related to their files in Nextcloud." : "Denna applikation tillåter användare att visa handlingar relaterade till deras filer i Nextcloud ",
    "Activity feed" : "Aktivitetsflöde",
    "Send activity emails" : "Skicka aktivitets-epost",
    "Default settings" : "Förvalda inställningar",
    "Configure the default activity settings for new users." : "Ställ in aktivitetsinställningar för nya användare",
    "List your own actions in the stream" : "Visa dina egna aktiviteter i aktivitetsflödet",
    "Notify about your own actions via email" : "Skicka notifieringsmail gällande dina egna aktiviteter",
    "You need to set up your email address before you can receive notification emails." : "Du måste ställa in din e-postadress innan du kan ta emot e-postmeddelanden.",
    "Send emails:" : "Skicka e-post:",
    "As soon as possible" : "Så snart som möjligt",
    "Hourly" : "Timvis",
    "Daily" : "Dagligen",
    "Weekly" : "Varje vecka",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Välj vilka typer av aktiviteter du vill ha en notis om via e-post och vilka som ska dyka upp i aktivitetsflödet.",
    "Choose which activities you want to see in your stream." : "Välj vilka aktiviteter du vill se i ditt flöde.",
    "Settings" : "Inställningar",
    "Enable RSS feed" : "Aktivera RSS-flöde",
    "RSS feed" : "RSS-flöde",
    "No more events to load" : "Inga fler aktiviteter.",
    "Files" : "Filer",
    "Activity notification" : "Notis om aktivitet"
},
"nplurals=2; plural=(n != 1);");
